/* Machine generated file -- Do NOT edit */

#include <afsconfig.h>
#include <afs/param.h>
#include <roken.h>
#ifdef AFS_NT40_ENV
#define AFS_RXGEN_EXPORT __declspec(dllexport)
#endif /* AFS_NT40_ENV */
#include "afsint.h"

#ifndef FSINT_COMMON_XG


bool_t
xdr_AFSFid(XDR *xdrs, AFSFid *objp)
{
	if (!xdr_afs_uint32(xdrs, &objp->Volume)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Vnode)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Unique)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSCallBack(XDR *xdrs, AFSCallBack *objp)
{
	if (!xdr_afs_uint32(xdrs, &objp->CallBackVersion)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ExpirationTime)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->CallBackType)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSDBLockDesc(XDR *xdrs, AFSDBLockDesc *objp)
{
	if (!xdr_char(xdrs, &objp->waitStates)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->exclLocked)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->readersReading)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->numWaiting)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->spare)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->pid_last_reader)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->pid_writer)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->src_indicator)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSDBCacheEntry(XDR *xdrs, AFSDBCacheEntry *objp)
{
	if (!xdr_afs_int32(xdrs, &objp->addr)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->cell)) {
		return (FALSE);
	}
	if (!xdr_AFSFid(xdrs, &objp->netFid)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->Length)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->DataVersion)) {
		return (FALSE);
	}
	if (!xdr_AFSDBLockDesc(xdrs, &objp->lock)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->callback)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->cbExpires)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->refCount)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->opens)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->writers)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->mvstat)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->states)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSDBCacheEntry64(XDR *xdrs, AFSDBCacheEntry64 *objp)
{
	if (!xdr_afs_int32(xdrs, &objp->addr)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->cell)) {
		return (FALSE);
	}
	if (!xdr_AFSFid(xdrs, &objp->netFid)) {
		return (FALSE);
	}
	if (!xdr_afs_int64(xdrs, &objp->Length)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->DataVersion)) {
		return (FALSE);
	}
	if (!xdr_AFSDBLockDesc(xdrs, &objp->lock)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->callback)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->cbExpires)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->refCount)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->opens)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->writers)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->mvstat)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->states)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSDBLock(XDR *xdrs, AFSDBLock *objp)
{
	if (!xdr_vector(xdrs, (char *) objp->name, 16, sizeof(char), (xdrproc_t) xdr_char)) {
		return (FALSE);
	}
	if (!xdr_AFSDBLockDesc(xdrs, &objp->lock)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSDEntry(XDR *xdrs, AFSDEntry *objp)
{
	if (!xdr_afs_int32(xdrs, &objp->addr)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->cell)) {
		return (FALSE);
	}
	if (!xdr_AFSFid(xdrs, &objp->netFid)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->Length)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->DataVersion)) {
		return (FALSE);
	}
	if (!xdr_AFSDBLockDesc(xdrs, &objp->lock)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->callback)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->cbExpires)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->refCount)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->opens)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->writers)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->mvstat)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->states)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSOpaque(XDR *xdrs, AFSOpaque *objp)
{
	{
		u_int __len = (u_int) *(&objp->AFSOpaque_len);
		if (!xdr_bytes(xdrs, (char **)&objp->AFSOpaque_val, &__len, AFSOPAQUEMAX)) {
			return (FALSE);
		}
		*(&objp->AFSOpaque_len) = __len;
	}
	return (TRUE);
}




bool_t
xdr_AFSCBFids(XDR *xdrs, AFSCBFids *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->AFSCBFids_val, &objp->AFSCBFids_len, AFSCBMAX, sizeof(AFSFid), (xdrproc_t) xdr_AFSFid)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSCBs(XDR *xdrs, AFSCBs *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->AFSCBs_val, &objp->AFSCBs_len, AFSCBMAX, sizeof(AFSCallBack), (xdrproc_t) xdr_AFSCallBack)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSCB_CollData(XDR *xdrs, AFSCB_CollData *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->AFSCB_CollData_val, &objp->AFSCB_CollData_len, AFSCB_MAX_XSTAT_LONGS, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFS_CollData(XDR *xdrs, AFS_CollData *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->AFS_CollData_val, &objp->AFS_CollData_len, AFS_MAX_XSTAT_LONGS, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_VolumeId(XDR *xdrs, VolumeId *objp)
{
	if (!xdr_afs_uint32(xdrs, objp)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_VolId(XDR *xdrs, VolId *objp)
{
	if (!xdr_afs_uint32(xdrs, objp)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_VnodeId(XDR *xdrs, VnodeId *objp)
{
	if (!xdr_afs_uint32(xdrs, objp)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_Unique(XDR *xdrs, Unique *objp)
{
	if (!xdr_afs_uint32(xdrs, objp)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_UserId(XDR *xdrs, UserId *objp)
{
	if (!xdr_afs_uint32(xdrs, objp)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_FileVersion(XDR *xdrs, FileVersion *objp)
{
	if (!xdr_afs_uint32(xdrs, objp)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_ErrorCode(XDR *xdrs, ErrorCode *objp)
{
	if (!xdr_afs_int32(xdrs, objp)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_Rights(XDR *xdrs, Rights *objp)
{
	if (!xdr_afs_int32(xdrs, objp)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_DiskName(XDR *xdrs, DiskName *objp)
{
	if (!xdr_opaque(xdrs, (caddr_t) objp, AFS_DISKNAMESIZE)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_interfaceAddr(XDR *xdrs, interfaceAddr *objp)
{
	if (!xdr_int(xdrs, &objp->numberOfInterfaces)) {
		return (FALSE);
	}
	if (!xdr_afsUUID(xdrs, &objp->uuid)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->addr_in, AFS_MAX_INTERFACE_ADDR, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->subnetmask, AFS_MAX_INTERFACE_ADDR, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->mtu, AFS_MAX_INTERFACE_ADDR, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_serverList(XDR *xdrs, serverList *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->serverList_val, &objp->serverList_len, AFSMAXCELLHOSTS, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_cacheConfig(XDR *xdrs, cacheConfig *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->cacheConfig_val, &objp->cacheConfig_len, ~0u, sizeof(afs_uint32), (xdrproc_t) xdr_afs_uint32)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_Capabilities(XDR *xdrs, Capabilities *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->Capabilities_val, &objp->Capabilities_len, AFSCAPABILITIESMAX, sizeof(afs_uint32), (xdrproc_t) xdr_afs_uint32)) {
		return (FALSE);
	}
	return (TRUE);
}


#endif /* FSINT_COMMON_XG */
#define VICECONNBAD 1234
#define VICETOKENDEAD 1235
#define AFS_LOCKWAIT (5*60)


bool_t
xdr_ViceDataType(XDR *xdrs, ViceDataType *objp)
{
	if (!xdr_afs_int32(xdrs, objp)) {
		return (FALSE);
	}
	return (TRUE);
}


#define Invalid 0
#define File 1
#define Directory 2
#define SymbolicLink 3
#ifdef KERNEL
#define afs_xdr_array(a,b,c,d,e,f) afs_xdr_arrayN(a,b,c,d,e,f)
#endif


bool_t
xdr_BD(XDR *xdrs, BD *objp)
{
	if (!xdr_afs_int32(xdrs, &objp->host)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->portal)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->session)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSVolSync(XDR *xdrs, AFSVolSync *objp)
{
	if (!xdr_afs_uint32(xdrs, &objp->spare1)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->spare2)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->spare3)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->spare4)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->spare5)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->spare6)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSOldFetchStatus(XDR *xdrs, AFSOldFetchStatus *objp)
{
	if (!xdr_afs_uint32(xdrs, &objp->InterfaceVersion)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->FileType)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->LinkCount)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Length)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->DataVersion)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Author)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Owner)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->CallerAccess)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->AnonymousAccess)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->UnixModeBits)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ParentVnode)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ParentUnique)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->SegSize)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ClientModTime)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ServerModTime)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Group)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSFetchStatus(XDR *xdrs, AFSFetchStatus *objp)
{
	if (!xdr_afs_uint32(xdrs, &objp->InterfaceVersion)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->FileType)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->LinkCount)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Length)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->DataVersion)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Author)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Owner)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->CallerAccess)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->AnonymousAccess)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->UnixModeBits)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ParentVnode)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ParentUnique)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ResidencyMask)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ClientModTime)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ServerModTime)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Group)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->SyncCounter)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->dataVersionHigh)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->lockCount)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Length_hi)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->errorCode)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSStoreStatus(XDR *xdrs, AFSStoreStatus *objp)
{
	if (!xdr_afs_uint32(xdrs, &objp->Mask)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ClientModTime)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Owner)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Group)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->UnixModeBits)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->SegSize)) {
		return (FALSE);
	}
	return (TRUE);
}


#define AFS_SETMODTIME 1
#define AFS_SETOWNER 2
#define AFS_SETGROUP 4
#define AFS_SETMODE 8
#define AFS_SETSEGSIZE 16
#define AFS_FSYNC 1024


bool_t
xdr_ViceVolumeType(XDR *xdrs, ViceVolumeType *objp)
{
	if (!xdr_afs_int32(xdrs, objp)) {
		return (FALSE);
	}
	return (TRUE);
}


#define ReadOnly 0
#define ReadWrite 1


bool_t
xdr_ViceDisk(XDR *xdrs, ViceDisk *objp)
{
	if (!xdr_afs_int32(xdrs, &objp->BlocksAvailable)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->TotalBlocks)) {
		return (FALSE);
	}
	if (!xdr_DiskName(xdrs, &objp->Name)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_ViceStatistics(XDR *xdrs, ViceStatistics *objp)
{
	if (!xdr_afs_uint32(xdrs, &objp->CurrentMsgNumber)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->OldestMsgNumber)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->CurrentTime)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->BootTime)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->StartTime)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->CurrentConnections)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->TotalViceCalls)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->TotalFetchs)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->FetchDatas)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->FetchedBytes)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->FetchDataRate)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->TotalStores)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->StoreDatas)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->StoredBytes)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->StoreDataRate)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->TotalRPCBytesSent)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->TotalRPCBytesReceived)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->TotalRPCPacketsSent)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->TotalRPCPacketsReceived)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->TotalRPCPacketsLost)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->TotalRPCBogusPackets)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->SystemCPU)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->UserCPU)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->NiceCPU)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->IdleCPU)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->TotalIO)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->ActiveVM)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->TotalVM)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->EtherNetTotalErrors)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->EtherNetTotalWrites)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->EtherNetTotalInterupts)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->EtherNetGoodReads)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->EtherNetTotalBytesWritten)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->EtherNetTotalBytesRead)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->ProcessSize)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->WorkStations)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->ActiveWorkStations)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->Spare1)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->Spare2)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->Spare3)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->Spare4)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->Spare5)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->Spare6)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->Spare7)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->Spare8)) {
		return (FALSE);
	}
	if (!xdr_ViceDisk(xdrs, &objp->Disk1)) {
		return (FALSE);
	}
	if (!xdr_ViceDisk(xdrs, &objp->Disk2)) {
		return (FALSE);
	}
	if (!xdr_ViceDisk(xdrs, &objp->Disk3)) {
		return (FALSE);
	}
	if (!xdr_ViceDisk(xdrs, &objp->Disk4)) {
		return (FALSE);
	}
	if (!xdr_ViceDisk(xdrs, &objp->Disk5)) {
		return (FALSE);
	}
	if (!xdr_ViceDisk(xdrs, &objp->Disk6)) {
		return (FALSE);
	}
	if (!xdr_ViceDisk(xdrs, &objp->Disk7)) {
		return (FALSE);
	}
	if (!xdr_ViceDisk(xdrs, &objp->Disk8)) {
		return (FALSE);
	}
	if (!xdr_ViceDisk(xdrs, &objp->Disk9)) {
		return (FALSE);
	}
	if (!xdr_ViceDisk(xdrs, &objp->Disk10)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_VolumeStatus(XDR *xdrs, VolumeStatus *objp)
{
	if (!xdr_afs_int32(xdrs, &objp->Vid)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->ParentId)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->Online)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->InService)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->Blessed)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->NeedsSalvage)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->Type)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->MinQuota)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->MaxQuota)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->BlocksInUse)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->PartBlocksAvail)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->PartMaxBlocks)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSFetchVolumeStatus(XDR *xdrs, AFSFetchVolumeStatus *objp)
{
	if (!xdr_afs_int32(xdrs, &objp->Vid)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->ParentId)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->Online)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->InService)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->Blessed)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->NeedsSalvage)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->Type)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->MinQuota)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->MaxQuota)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->BlocksInUse)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->PartBlocksAvail)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->PartMaxBlocks)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSStoreVolumeStatus(XDR *xdrs, AFSStoreVolumeStatus *objp)
{
	if (!xdr_afs_int32(xdrs, &objp->Mask)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->MinQuota)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->MaxQuota)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSVolumeInfo(XDR *xdrs, AFSVolumeInfo *objp)
{
	if (!xdr_afs_uint32(xdrs, &objp->Vid)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->Type)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type0)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type1)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type2)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type3)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type4)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ServerCount)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server0)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server1)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server2)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server3)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server4)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server5)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server6)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server7)) {
		return (FALSE);
	}
	if (!xdr_u_short(xdrs, &objp->Port0)) {
		return (FALSE);
	}
	if (!xdr_u_short(xdrs, &objp->Port1)) {
		return (FALSE);
	}
	if (!xdr_u_short(xdrs, &objp->Port2)) {
		return (FALSE);
	}
	if (!xdr_u_short(xdrs, &objp->Port3)) {
		return (FALSE);
	}
	if (!xdr_u_short(xdrs, &objp->Port4)) {
		return (FALSE);
	}
	if (!xdr_u_short(xdrs, &objp->Port5)) {
		return (FALSE);
	}
	if (!xdr_u_short(xdrs, &objp->Port6)) {
		return (FALSE);
	}
	if (!xdr_u_short(xdrs, &objp->Port7)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_VolumeInfo(XDR *xdrs, VolumeInfo *objp)
{
	if (!xdr_afs_uint32(xdrs, &objp->Vid)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->Type)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type0)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type1)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type2)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type3)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type4)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ServerCount)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server0)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server1)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server2)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server3)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server4)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server5)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server6)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Server7)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_ViceLockType(XDR *xdrs, ViceLockType *objp)
{
	if (!xdr_afs_int32(xdrs, objp)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AFSBulkStats(XDR *xdrs, AFSBulkStats *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->AFSBulkStats_val, &objp->AFSBulkStats_len, AFSCBMAX, sizeof(AFSFetchStatus), (xdrproc_t) xdr_AFSFetchStatus)) {
		return (FALSE);
	}
	return (TRUE);
}


#define LockRead 0
#define LockWrite 1
#define LockExtend 2
#define LockRelease 3


bool_t
xdr_ViceOfflineType(XDR *xdrs, ViceOfflineType *objp)
{
	if (!xdr_afs_int32(xdrs, objp)) {
		return (FALSE);
	}
	return (TRUE);
}


#define NoSalvage 0
#define Salvage 1
#define MAXCMDINT64S 3
#define MAXCMDINT32S 200
#define MAXCMDCHARS 256
#define CMD_GETRESIDENCIES 1
#define CMD_CHANGERESIDENCIES 2
#define CMD_IMPORTRESIDENCIES 3
#define CMD_GETEXTVOLATTR 4
#define CMD_SETEXTVOLATTR 5
#define CMD_GETACCESSHISTORY 6
#define CMD_MIGRATEFILE 7
#define CMD_CHECKHSMMETADATA 8
#define CMD_FETCHSTATUS 9
#define VOLATTR_DESIREDRESIDENCYMASK 1
#define VOLATTR_UNDESIREDRESIDENCYMASK 2
#define VOLATTR_SETSPECIALACCESSFLAG 4


bool_t
xdr_ExtendedVolAttrInputs(XDR *xdrs, ExtendedVolAttrInputs *objp)
{
	if (!xdr_afs_uint32(xdrs, &objp->Mask)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Volume)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->DesiredResidencyMask)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->Spare1, 10, sizeof(afs_uint32), (xdrproc_t) xdr_afs_uint32)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->UnDesiredResidencyMask)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->Spare2, 9, sizeof(afs_uint32), (xdrproc_t) xdr_afs_uint32)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->SpecialAccessFlag)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_ExtendedVolAttrOutputs(XDR *xdrs, ExtendedVolAttrOutputs *objp)
{
	if (!xdr_afs_uint32(xdrs, &objp->DesiredResidencyMask)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->Spare1, 10, sizeof(afs_uint32), (xdrproc_t) xdr_afs_uint32)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->UnDesiredResidencyMask)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->Spare2, 9, sizeof(afs_uint32), (xdrproc_t) xdr_afs_uint32)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->SpecialAccessFlag)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_TagsArray(XDR *xdrs, TagsArray *objp)
{
	if (!xdr_afs_uint32(xdrs, &objp->TagsArray_len)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->TagsArray_val, 184, sizeof(afs_uint32), (xdrproc_t) xdr_afs_uint32)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AccessHistory(XDR *xdrs, AccessHistory *objp)
{
	if (!xdr_afs_uint64(xdrs, &objp->Size)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ModTime)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->NonSpoolingFetches)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->UserSpoolingFetches)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->MigratorSpoolingFetches)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->LastUserMigrationEvent)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->MigrateMe)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Time0)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type0)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->LocalAccess0)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Residency0)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Time1)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type1)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->LocalAccess1)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Residency1)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Time2)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type2)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->LocalAccess2)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Residency2)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Time3)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type3)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->LocalAccess3)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Residency3)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Time4)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type4)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->LocalAccess4)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Residency4)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_AccessHistoryOld(XDR *xdrs, AccessHistoryOld *objp)
{
	if (!xdr_afs_uint32(xdrs, &objp->Size)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->ModTime)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->NonSpoolingFetches)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->UserSpoolingFetches)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->MigratorSpoolingFetches)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->LastUserMigrationEvent)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->MigrateMe)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Time0)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type0)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->LocalAccess0)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Residency0)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Time1)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type1)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->LocalAccess1)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Residency1)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Time2)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type2)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->LocalAccess2)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Residency2)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Time3)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type3)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->LocalAccess3)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Residency3)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Time4)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Type4)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->LocalAccess4)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->Residency4)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_FsCmdInputs(XDR *xdrs, FsCmdInputs *objp)
{
	if (!xdr_afs_int32(xdrs, &objp->command)) {
		return (FALSE);
	}
	if (!xdr_AFSFid(xdrs, &objp->fid)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->int64s, MAXCMDINT64S, sizeof(afs_int64), (xdrproc_t) xdr_afs_int64)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->int32s, MAXCMDINT32S, sizeof(afs_uint32), (xdrproc_t) xdr_afs_uint32)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->chars, MAXCMDCHARS, sizeof(char), (xdrproc_t) xdr_char)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_FsCmdOutputs(XDR *xdrs, FsCmdOutputs *objp)
{
	if (!xdr_afs_int32(xdrs, &objp->code)) {
		return (FALSE);
	}
	if (!xdr_AFSFetchStatus(xdrs, &objp->status)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->int64s, MAXCMDINT64S, sizeof(afs_int64), (xdrproc_t) xdr_afs_int64)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->int32s, MAXCMDINT32S, sizeof(afs_uint32), (xdrproc_t) xdr_afs_uint32)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->chars, MAXCMDCHARS, sizeof(char), (xdrproc_t) xdr_char)) {
		return (FALSE);
	}
	return (TRUE);
}


#define ResidencyCmdInputs FsCmdInputs
#define ResidencyCmdOutputs FsCmdOutputs


bool_t
xdr_ViceIds(XDR *xdrs, ViceIds *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->ViceIds_val, &objp->ViceIds_len, FLUSHMAX, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_IPAddrs(XDR *xdrs, IPAddrs *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->IPAddrs_val, &objp->IPAddrs_len, FLUSHMAX, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	return (TRUE);
}


#define STATS64_CURRENTTIME 0
#define STATS64_BOOTTIME 1
#define STATS64_STARTTIME 2
#define STATS64_CURRENTCONNECTIONS 3
#define STATS64_TOTALFETCHES 4
#define STATS64_FETCHDATAS 5
#define STATS64_FETCHEDBYTES 6
#define STATS64_FETCHDATARATE 7
#define STATS64_TOTALSTORES 8
#define STATS64_STOREDATAS 9
#define STATS64_STOREDBYTES 10
#define STATS64_STOREDATARATE 11
#define STATS64_TOTALVICECALLS 12
#define STATS64_WORKSTATIONS 13
#define STATS64_ACTIVEWORKSTATIONS 14
#define STATS64_PROCESSSIZE 15


bool_t
xdr_ViceStatistics64(XDR *xdrs, ViceStatistics64 *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->ViceStatistics64_val, &objp->ViceStatistics64_len, STATS64_VERSION, sizeof(afs_uint64), (xdrproc_t) xdr_afs_uint64)) {
		return (FALSE);
	}
	return (TRUE);
}


AFS_RXGEN_EXPORT
const char *RXAFS_function_names[] = {
	"RXAFS_FetchData",
	"RXAFS_FetchACL",
	"RXAFS_FetchStatus",
	"RXAFS_StoreData",
	"RXAFS_OldStoreACL",
	"RXAFS_StoreStatus",
	"RXAFS_RemoveFile",
	"RXAFS_CreateFile",
	"RXAFS_Rename",
	"RXAFS_Symlink",
	"RXAFS_Link",
	"RXAFS_MakeDir",
	"RXAFS_RemoveDir",
	"RXAFS_OldSetLock",
	"RXAFS_OldExtendLock",
	"RXAFS_OldReleaseLock",
	"RXAFS_GetStatistics",
	"RXAFS_GiveUpCallBacks",
	"RXAFS_GetVolumeInfo",
	"RXAFS_GetVolumeStatus",
	"RXAFS_SetVolumeStatus",
	"RXAFS_GetRootVolume",
	"RXAFS_CheckToken",
	"RXAFS_GetTime",
	"RXAFS_NGetVolumeInfo",
	"RXAFS_BulkStatus",
	"RXAFS_SetLock",
	"RXAFS_ExtendLock",
	"RXAFS_ReleaseLock",
	"RXAFS_XStatsVersion",
	"RXAFS_GetXStats",
	"RXAFS_Lookup",
	"RXAFS_FlushCPS",
	"RXAFS_DFSSymlink",
	"RXAFS_FsCmd",
	"RXAFS_InlineBulkStatus",
	"RXAFS_FetchData64",
	"RXAFS_StoreData64",
	"RXAFS_GiveUpAllCallBacks",
	"RXAFS_GetCapabilities",
	"RXAFS_CallBackRxConnAddr",
	"RXAFS_GetStatistics64",
	"RXAFS_StoreACL"
};
char *RXAFS_TranslateOpCode(int op)
{
	switch (op) {
		case 131:	return "RXAFS_FetchACL";
		case 132:	return "RXAFS_FetchStatus";
		case 134:	return "RXAFS_OldStoreACL";
		case 135:	return "RXAFS_StoreStatus";
		case 136:	return "RXAFS_RemoveFile";
		case 137:	return "RXAFS_CreateFile";
		case 138:	return "RXAFS_Rename";
		case 139:	return "RXAFS_Symlink";
		case 140:	return "RXAFS_Link";
		case 141:	return "RXAFS_MakeDir";
		case 142:	return "RXAFS_RemoveDir";
		case 143:	return "RXAFS_OldSetLock";
		case 144:	return "RXAFS_OldExtendLock";
		case 145:	return "RXAFS_OldReleaseLock";
		case 146:	return "RXAFS_GetStatistics";
		case 147:	return "RXAFS_GiveUpCallBacks";
		case 148:	return "RXAFS_GetVolumeInfo";
		case 149:	return "RXAFS_GetVolumeStatus";
		case 150:	return "RXAFS_SetVolumeStatus";
		case 151:	return "RXAFS_GetRootVolume";
		case 152:	return "RXAFS_CheckToken";
		case 153:	return "RXAFS_GetTime";
		case 154:	return "RXAFS_NGetVolumeInfo";
		case 155:	return "RXAFS_BulkStatus";
		case 156:	return "RXAFS_SetLock";
		case 157:	return "RXAFS_ExtendLock";
		case 158:	return "RXAFS_ReleaseLock";
		case 159:	return "RXAFS_XStatsVersion";
		case 160:	return "RXAFS_GetXStats";
		case 161:	return "RXAFS_Lookup";
		case 162:	return "RXAFS_FlushCPS";
		case 163:	return "RXAFS_DFSSymlink";
		case 220:	return "RXAFS_FsCmd";
		case 65536:	return "RXAFS_InlineBulkStatus";
		case 65539:	return "RXAFS_GiveUpAllCallBacks";
		case 65540:	return "RXAFS_GetCapabilities";
		case 65541:	return "RXAFS_CallBackRxConnAddr";
		case 65542:	return "RXAFS_GetStatistics64";
		case 164:	return "RXAFS_StoreACL";
		default:
			return NULL;
	}
}
int RXAFS_OpCodeIndex(int op)
{
	switch (op) {
		case 131:	return 1;
		case 132:	return 2;
		case 134:	return 4;
		case 135:	return 5;
		case 136:	return 6;
		case 137:	return 7;
		case 138:	return 8;
		case 139:	return 9;
		case 140:	return 10;
		case 141:	return 11;
		case 142:	return 12;
		case 143:	return 13;
		case 144:	return 14;
		case 145:	return 15;
		case 146:	return 16;
		case 147:	return 17;
		case 148:	return 18;
		case 149:	return 19;
		case 150:	return 20;
		case 151:	return 21;
		case 152:	return 22;
		case 153:	return 23;
		case 154:	return 24;
		case 155:	return 25;
		case 156:	return 26;
		case 157:	return 27;
		case 158:	return 28;
		case 159:	return 29;
		case 160:	return 30;
		case 161:	return 31;
		case 162:	return 32;
		case 163:	return 33;
		case 220:	return 34;
		case 65536:	return 35;
		case 65539:	return 38;
		case 65540:	return 39;
		case 65541:	return 40;
		case 65542:	return 41;
		case 164:	return 42;
		default:
			return -1;
	}
}
